==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://trac.rezo.net/spip/spip/ecrire/lang/
if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Accueil du site',
'articles' => 'Articles',
'articles_auteur' => 'Articles de cet auteur',
'articles_populaires' => 'Articles les plus populaires',
'articles_rubrique' => 'Articles de cette rubrique',
'aucun_article' => 'Il n\'y a pas d\'article &agrave; cette adresse',
'aucun_auteur' => 'Il n\'y a pas d\'auteur &agrave; cette adresse',
'aucun_site' => 'Il n\'y a pas de site &agrave; cette adresse',
'aucune_breve' => 'Il n\'y a pas de br&egrave;ve &agrave; cette adresse',
'aucune_rubrique' => 'Il n\'y a pas de rubrique &agrave; cette adresse',
'autres' => 'Autres',
'autres_breves' => 'Autres br&egrave;ves',
'autres_groupes_mots_clefs' => 'Autres groupes de mots-cl&eacute;s',
'autres_sites' => 'Autres sites',

// B
'bonjour' => 'Bonjour',
'breves' => 'Br&egrave;ves',

// C
'commenter_site' => 'Commenter ce site',
'copie_document_impossible' => 'Impossible de copier le document',

// D
'date' => 'Date',
'dernier_ajout' => 'Dernier ajout',
'dernieres_breves' => 'Derni&egrave;res br&egrave;ves',
'derniers_articles' => 'Derniers articles',
'derniers_commentaires' => 'Derniers commentaires',
'derniers_messages_forum' => 'Derniers messages publi&eacute;s dans les forums',
'documents_interdits_forum' => 'Documents interdits dans le forum',

// E
'edition_mode_texte' => '&Eacute;dition en mode texte de',
'en_reponse' => 'En r&eacute;ponse &agrave;&nbsp;:',
'en_resume' => 'En r&eacute;sum&eacute;',
'envoyer_message' => 'Envoyer un message',
'espace_prive' => 'Espace priv&eacute;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Hi&eacute;rarchie du site',

// J
'jours' => 'jours',

// L
'lien_connecter' => 'Se connecter',

// M
'meme_auteur' => 'Du m&ecirc;me auteur',
'meme_rubrique' => 'Dans la m&ecirc;me rubrique',
'memes_auteurs' => 'Des m&ecirc;mes auteurs',
'message' => 'Message',
'messages_forum' => 'Messages de forum',
'messages_recents' => 'Messages de forums les plus r&eacute;cents',
'mots_clefs' => 'Mots-cl&eacute;s',
'mots_clefs_meme_groupe' => 'Mots-cl&eacute;s dans le m&ecirc;me groupe',

// N
'navigation' => 'Navigation',
'nom' => 'Nom',
'nouveautes' => 'Les nouveaut&eacute;s',
'nouveautes_web' => 'Nouveaut&eacute;s sur le Web',
'nouveaux_articles' => 'Nouveaux articles',
'nouvelles_breves' => 'Nouvelles br&egrave;ves',

// P
'page_precedente' => 'page pr&eacute;c&eacute;dente',
'page_suivante' => 'page suivante',
'par_auteur' => 'par ',
'participer_site' => 'Vous pouvez participer &agrave; la vie de ce site et proposer vos propres articles en vous inscrivant ci-dessous. Vous recevrez imm&eacute;diatement un email vous indiquant vos codes d\'acc&egrave;s &agrave; l\'espace priv&eacute; du site.',
'plan_site' => 'Plan du site',
'popularite' => 'Popularit&eacute;',
'poster_message' => 'Poster un message',
'proposer_site' => 'Vous pouvez proposer un site &agrave; ajouter dans cette rubrique&nbsp;:',

// R
'repondre_article' => 'R&eacute;pondre &agrave; cet article',
'repondre_breve' => 'R&eacute;pondre &agrave; cette br&egrave;ve',
'repondre_message' => 'R&eacute;pondre &agrave; ce message',
'resultats_recherche' => 'R&eacute;sultats de la recherche',
'retour_debut_forums' => 'Retour au d&eacute;but des forums',
'rubrique' => 'Rubrique',
'rubriques' => 'Rubriques',

// S
'signatures_petition' => 'Signatures',
'site_realise_avec_spip' => 'Site r&eacute;alis&eacute; avec SPIP',
'sites_web' => 'Sites Web',
'sous_rubriques' => 'Sous-rubriques',
'spam' => 'Spam',
'suite' => 'suite',
'sur_web' => 'Sur le Web',
'syndiquer_rubrique' => 'Syndiquer cette rubrique',
'syndiquer_site' => 'Syndiquer tout le site',

// T
'texte_lettre_information' => 'Voici la lettre d\'information du site',
'texte_lettre_information_2' => 'Cette lettre recense les articles et les br&egrave;ves publi&eacute;s depuis',

// V
'ver_imprimer' => 'Version &agrave; imprimer',
'voir_en_ligne' => 'Voir en ligne',
'voir_squelette' => 'voir le squelette de cette page'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_fr.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// Fichier source, a modifier dans svn://trac.rezo.net/spip/branches/spip-2.1/ecrire/lang/
if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Accueil du site',
'article' => 'Article',
'articles' => 'Articles',
'articles_auteur' => 'Articles de cet auteur',
'articles_populaires' => 'Articles les plus populaires',
'articles_rubrique' => 'Articles de cette rubrique',
'aucun_article' => 'Il n\'y a pas d\'article &agrave; cette adresse',
'aucun_auteur' => 'Il n\'y a pas d\'auteur &agrave; cette adresse',
'aucun_site' => 'Il n\'y a pas de site &agrave; cette adresse',
'aucune_breve' => 'Il n\'y a pas de br&egrave;ve &agrave; cette adresse',
'aucune_rubrique' => 'Il n\'y a pas de rubrique &agrave; cette adresse',
'auteur' => 'Auteur',
'autres' => 'Autres',
'autres_breves' => 'Autres br&egrave;ves',
'autres_groupes_mots_clefs' => 'Autres groupes de mots-cl&eacute;s',
'autres_sites' => 'Autres sites',

// B
'bonjour' => 'Bonjour',
'breve' => 'Br&egrave;ve',
'breves' => 'Br&egrave;ves',

// C
'commenter_site' => 'Commenter ce site',
'copie_document_impossible' => 'Impossible de copier le document',

// D
'date' => 'Date',
'dernier_ajout' => 'Dernier ajout',
'dernieres_breves' => 'Derni&egrave;res br&egrave;ves',
'derniers_articles' => 'Derniers articles',
'derniers_commentaires' => 'Derniers commentaires',
'derniers_messages_forum' => 'Derniers messages publi&eacute;s dans les forums',
'documents_interdits_forum' => 'Documents interdits dans le forum',

// E
'edition_mode_texte' => '&Eacute;dition en mode texte de',
'en_reponse' => 'En r&eacute;ponse &agrave;&nbsp;:',
'en_resume' => 'En r&eacute;sum&eacute;',
'envoyer_message' => 'Envoyer un message',
'espace_prive' => 'Espace priv&eacute;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.',
'forum' => 'Forum',

// H
'hierarchie_site' => 'Hi&eacute;rarchie du site',

// J
'jours' => 'jours',

// L
'lien_connecter' => 'Se connecter',

// M
'meme_auteur' => 'Du m&ecirc;me auteur',
'meme_rubrique' => 'Dans la m&ecirc;me rubrique',
'memes_auteurs' => 'Des m&ecirc;mes auteurs',
'message' => 'Message',
'messages_forum' => 'Messages de forum',
'messages_recents' => 'Messages de forums les plus r&eacute;cents',
'mots_clef' => 'Mot-cl&eacute;',
'mots_clefs' => 'Mots-cl&eacute;s',
'mots_clefs_meme_groupe' => 'Mots-cl&eacute;s dans le m&ecirc;me groupe',

// N
'navigation' => 'Navigation',
'nom' => 'Nom',
'nouveautes' => 'Les nouveaut&eacute;s',
'nouveautes_web' => 'Nouveaut&eacute;s sur le Web',
'nouveaux_articles' => 'Nouveaux articles',
'nouvelles_breves' => 'Nouvelles br&egrave;ves',

// P
'page_precedente' => 'page pr&eacute;c&eacute;dente',
'page_suivante' => 'page suivante',
'par_auteur' => 'par ',
'participer_site' => 'Vous pouvez participer &agrave; la vie de ce site et proposer vos propres articles en vous inscrivant ci-dessous. Vous recevrez imm&eacute;diatement un email vous indiquant vos codes d\'acc&egrave;s &agrave; l\'espace priv&eacute; du site.',
'plan_site' => 'Plan du site',
'popularite' => 'Popularit&eacute;',
'poster_message' => 'Poster un message',
'proposer_site' => 'Vous pouvez proposer un site &agrave; ajouter dans cette rubrique&nbsp;:',

// R
'repondre_article' => 'R&eacute;pondre &agrave; cet article',
'repondre_breve' => 'R&eacute;pondre &agrave; cette br&egrave;ve',
'repondre_message' => 'R&eacute;pondre &agrave; ce message',
'resultats_recherche' => 'R&eacute;sultats de la recherche',
'retour_debut_forums' => 'Retour au d&eacute;but des forums',
'rubrique' => 'Rubrique',
'rubriques' => 'Rubriques',

// S
'signatures_petition' => 'Signatures',
'site_realise_avec_spip' => 'Site r&eacute;alis&eacute; avec SPIP',
'sites_web' => 'Sites Web',
'sous_rubriques' => 'Sous-rubriques',
'spam' => 'Spam',
'suite' => 'suite',
'sur_web' => 'Sur le Web',
'syndiquer_rubrique' => 'Syndiquer cette rubrique',
'syndiquer_site' => 'Syndiquer tout le site',

// T
'texte_lettre_information' => 'Voici la lettre d\'information du site',
'texte_lettre_information_2' => 'Cette lettre recense les articles et les br&egrave;ves publi&eacute;s depuis',

// V
'ver_imprimer' => 'Version &agrave; imprimer',
'voir_en_ligne' => 'Voir en ligne',
'voir_squelette' => 'voir le squelette de cette page'
);

?>
